@@ -44,7 +44,8 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
   if (length(which(ls() == "rmc.headername.recordingid")) == 0) rmc.headername.recordingid = c()
   if (length(which(ls() == "rmc.header.structure")) == 0) rmc.header.structure = c()
   if (length(which(ls() == "rmc.check4timegaps")) == 0) rmc.check4timegaps = FALSE
-  if (length(which(ls() == "rmc.noise")) == 0) rmc.noise = FALSE
+  if (length(which(ls() == "rmc.noise")) == 0) rmc.noise = c()
+  if (length(which(ls() == "rmc.col.wear")) == 0) rmc.col.wear = c()
   metrics2do = data.frame(do.bfen,do.enmo,do.lfenmo,do.en,do.hfen,
                           do.hfenplus,do.mad,do.anglex,do.angley,do.anglez,do.roll_med_acc_x,do.roll_med_acc_y,do.roll_med_acc_z,
                           do.dev_roll_med_acc_x,do.dev_roll_med_acc_y,do.dev_roll_med_acc_z,do.enmoa,do.lfen)
@@ -62,8 +63,8 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
   filename = filename[length(filename)]
   #   #parameters
   ws3 = windowsizes[1] ; ws2 = windowsizes[2]; ws = windowsizes[3]  #window sizes
-  if ((ws2/300) != round(ws2/300)) {
-    ws2 = as.numeric(300 * round(ws2/300))
+  if ((ws2/60) != round(ws2/60)) {
+    ws2 = as.numeric(60 * round(ws2/60))
     cat("\nWARNING: The long windowsize needs to be a multitude of five minutes periods. The\n")
     cat(paste("\nlong windowsize has now been automatically adjusted to: ",ws2," seconds in order to meet this criteria.\n",sep=""))
   }
@@ -146,6 +147,42 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
   if (mon == 4 & dformat == 4) blocksize = round(blocksize * 1.0043)
   if (mon == 4 & dformat == 2) blocksize = round(blocksize)
   id = g.getidfromheaderobject(filename=filename,header=header,dformat=dformat,mon=mon)
+  #Clipping threshold: estimate number of data points of clipping based on raw data at about 87 Hz
+  if (length(dynrange) > 0) {
+    clipthres = dynrange - 0.5
+  } else {
+    if (mon == 1) {
+      clipthres = 5.5
+    } else if (mon == 2) {
+      clipthres = 7.5
+    } else if (mon == 3) {
+      clipthres = 7.5 # hard coded assumption that dynamic range is 8g
+    } else if (mon == 4) {
+      clipthres = 7.5 # hard coded assumption that dynamic range is 8g
+    } else if (mon == 5) {
+      clipthres = rmc.dynamic_range
+    }
+  }
+  # Nonwear threshold: #non-wear criteria are monitor specific
+  racriter = 0.15 #very likely irrelevant parameters, but leave in for consistency
+  if (mon == 1) {
+    sdcriter = 0.003
+    racriter = 0.05
+  } else if (mon == 2) {
+    sdcriter = 0.013 #0.0109 in rest test
+  } else if (mon == 3) {
+    sdcriter = 0.013 #ADJUSTMENT NEEDED FOR ACTIGRAPH???????????
+  } else if (mon == 4) {
+    sdcriter = 0.013 #ADJUSTMENT NEEDED FOR Axivity???????????
+  } else if (mon == 5) {
+    if (length(rmc.noise) == 0) {
+      warning("Argument rmc.noise not specified, please specify expected noise level in g-units")
+    }
+    sdcriter = rmc.noise * 1.2
+    if (length(rmc.noise) == 0) {
+      stop("Please provide noise level for the acceleration sensors in g-units with argument rmc.noise to aid non-wear detection")
+    }
+  }
   #creating matrixes for storing output
   S = matrix(0,0,4) #dummy variable needed to cope with head-tailing succeeding blocks of data
   nev = 80*10^7 # number expected values
@@ -205,7 +242,8 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
                               rmc.headername.sn = rmc.headername.sn,
                               rmc.headername.recordingid = rmc.headername.sn,
                               rmc.header.structure = rmc.header.structure,
-                              rmc.check4timegaps = rmc.check4timegaps)
+                              rmc.check4timegaps = rmc.check4timegaps,
+                              rmc.col.wear=rmc.col.wear)
       P = accread$P
       filequality = accread$filequality
       filetooshort = filequality$filetooshort
@@ -231,7 +269,6 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
         P = c()
       }
     }
-
     if (length(P) > 0) { #would have been set to zero if file was corrupt or empty
       if (useRDA == FALSE) {
         if (mon == 1 & dformat == 1) {
@@ -249,13 +286,12 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
         if (nrow(S) > 0) {
           data = rbind(S,data)
         }
-
         if (temp.available == TRUE) {
           use.temp = TRUE
         } else {
           use.temp = FALSE
         }
-        if (mon == 2 | (mon == 4 & dformat == 4) | (mon == 5 & temp.available == TRUE)) {
+        if (mon == 2 | (mon == 4 & dformat == 4) | (mon == 5 & use.temp == TRUE)) {
           if (mon == 2) tempcolumn = 7
           if (mon == 4 | mon == 5) tempcolumn = 5
           meantemp = mean(as.numeric(data[,tempcolumn]),na.rm=TRUE)
@@ -317,8 +353,7 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
           start_min = start_min +1 #shift in minutes needed (+1 one to account for seconds comp)
           #-----------
           minshift = start_meas - (((start_min/start_meas) - floor(start_min/start_meas)) * start_meas)
-          # minshift = minshift - 1 # Removed as suggested by E Mirkes
-          if (minshift == start_meas) minshift = 0; # Addition as suggested by E Mirkes: One of my files has the first record at 2016-02-11 13:14:55 but the resulting file contains data from 2016-02-11 13:30:00. It means that we lost 15 minutes.
+          if (minshift == start_meas) minshift = 0; 
           #-----------
           sampleshift = (minshift*60*sf) + (secshift*sf) #derive sample shift
           data = data[-c(1:floor(sampleshift)),] #delete data accordingly
@@ -397,13 +432,21 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
           durexp = nrow(data) / (sf*ws)	#duration of experiment in hrs
           data = as.matrix(data)
           #--------------------------------------------
-          if (mon == 2 | (mon == 4 & dformat == 4)) {
+          if (mon == 2 | (mon == 4 & dformat == 4) | mon == 5) {
             if (mon == 2) {
               temperaturecolumn = 7; lightcolumn = 5
             } else if (mon ==4) {
               temperaturecolumn = 5; lightcolumn = 7
+            } else if (mon ==5) {
+              temperaturecolumn = 5 # because currently we do not extract light with read.myacc.csv
+            }
+            if (mon != 5) {
+              light = as.numeric(data[,lightcolumn])
+            } 
+            if (mon == 5 & length(rmc.col.wear) > 0) {
+              wearcol = as.character(data[, which(colnames(data) == "wear")])
+              suppressWarnings(storage.mode(wearcola) <- "logical")
             }
-            light = as.numeric(data[,lightcolumn])
             temperature = as.numeric(data[,temperaturecolumn])
           }
           # Initialization of variables
@@ -422,17 +465,23 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
             data[,1:3] = scale(as.matrix(data[,1:3]),center = -offset, scale = 1/scale) +
               scale(yy, center = rep(meantemp,3), scale = 1/tempoffset)  #rescale data
             rm(yy); gc()
-          } else if (dformat == 2 & (mon != 4)) {
-            if (mon == 2) {
-              yy = as.matrix(cbind(as.numeric(data[,7]),as.numeric(data[,7]),as.numeric(data[,7])))
-              meantemp = mean(as.numeric(data[,7]))
+          } else if ((dformat == 2 | dformat == 5) & (mon != 4)) {
+            if (mon == 2 | (mon == 5 & use.temp == TRUE)) {
+              tempcolumnvalues = as.numeric(as.character(data[,temperaturecolumn]))
+              yy = as.matrix(cbind(tempcolumnvalues, tempcolumnvalues, tempcolumnvalues))
+              meantemp = mean(as.numeric(data[,temperaturecolumn]))
               if (length(meantempcal) == 0) meantempcal = meantemp
             }
             if (ncol(data) == 3) data = data[,1:3]
-            if (ncol(data) >= 4) data = data[,2:4]
-            if (mon == 3) {
+            if (ncol(data) >= 4) {
+              data = data[,2:4]
+              if (class(data[,1]) == "character") {
+                data = apply(data, 2,as.numeric)
+              }
+            }
+            if ((mon == 3 | mon == 5) & use.temp == FALSE) {
               data[,1:3] = scale(data[,1:3],center = -offset, scale = 1/scale)  #rescale data
-            } else if (mon == 2) {
+            } else if ((mon == 2 | mon == 5) & use.temp == TRUE) {
               # meantemp replaced by meantempcal # 19-12-2013
               data[,1:3] = scale(data[,1:3],center = -offset, scale = 1/scale) +
                 scale(yy, center = rep(meantempcal,3), scale = 1/tempoffset)  #rescale data
@@ -564,69 +613,41 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
         nmin = floor(LD/(window2)) #nmin = minimum number of windows that fit in this block of data
         CW = NW = matrix(0,nmin,3) #CW is clipping, NW is non-wear
         TS1W = TS2W = TS3W = TS4W = TS5W = TS6W = TS7W = CWav = NWav = matrix(0,nmin,1)
+        crit = ((window/window2)/2)+1
         for (h in 1: nmin) { #number of windows
           cliphoc1 = (((h-1)*window2)+ window2*0.5 ) - window2*0.5 #does not use "window"
           cliphoc2 = (((h-1)*window2)+ window2*0.5 ) + window2*0.5
+          if (h <= crit) {
+            hoc1 = 1
+            hoc2 = window
+          } else if (h >= (nmin - crit)) {
+            hoc1 = (nmin-crit)*window2
+            hoc2 = nmin*window2 #end of data
+          } else if (h > crit & h < (nmin - crit)) {
+            hoc1=(((h-1)*window2)+ window2*0.5 ) - window*0.5
+            hoc2=(((h-1)*window2)+ window2*0.5 ) + window*0.5
+          }
+          if (length(rmc.col.wear) > 0) {
+            wearTable = table(wearcol[(1+hoc1):hoc2], useNA = FALSE)
+            NWav[h,1] = as.logical(tail(names(sort(wearTable)), 1)) * 3 # times 3 to simulate heuristic approach
+          } 
           for (jj in  1:3) {
             #hoc1 & hoc2 = edges of windows
             #window is bigger& window2 is smaller one
-            crit = ((window/window2)/2)+1
-            if (h <= crit) {
-              hoc1 = 1
-              hoc2 = window
-            } else if (h >= (nmin - crit)) {
-              hoc1 = (nmin-crit)*window2
-              hoc2 = nmin*window2 #end of data
-            } else if (h > crit & h < (nmin - crit)) {
-              hoc1=(((h-1)*window2)+ window2*0.5 ) - window*0.5
-              hoc2=(((h-1)*window2)+ window2*0.5 ) + window*0.5
-            }
             sdwacc = sd(as.numeric(data[(1+hoc1):hoc2,jj]),na.rm=TRUE)
             maxwacc = max(as.numeric(data[(1+hoc1):hoc2,jj]),na.rm=TRUE)
             minwacc = min(as.numeric(data[(1+hoc1):hoc2,jj]),na.rm=TRUE)
-            #estimate number of data points of clipping based on raw data at about 87 Hz
-            if (length(dynrange) > 0) {
-              clipthres = dynrange - 0.5
-            } else {
-              if (mon == 1) {
-                clipthres = 5.5
-              } else if (mon == 2) {
-                clipthres = 7.5
-              } else if (mon == 3) {
-                clipthres = 7.5 # hard coded assumption that dynamic range is 8g
-              } else if (mon == 4) {
-                clipthres = 7.5 # hard coded assumption that dynamic range is 8g
-              } else if (mon == 5) {
-                clipthres = rmc.dynamic_range
-              }
-            }
             CW[h,jj] = length(which(abs(as.numeric(data[(1+cliphoc1):cliphoc2,jj])) > clipthres))
-            #non-wear criteria are monitor specific
-            racriter = 0.15 #very likely irrelevant parameters, but leave in for consistency
-            if (mon == 1) {
-              sdcriter = 0.003
-              racriter = 0.05
-            } else if (mon == 2) {
-              sdcriter = 0.013 #0.0109 in rest test
-            } else if (mon == 3) {
-              sdcriter = 0.013 #ADJUSTMENT NEEDED FOR ACTIGRAPH???????????
-            } else if (mon == 4) {
-              sdcriter = 0.013 #ADJUSTMENT NEEDED FOR Axivity???????????
-            } else if (mon == 5) {
-              sdcriter = rmc.noise * 1.2
-              if (length(rmc.noise) == 0) {
-                stop("Please provide noise level for the acceleration sensors in g-units with argument rmc.noise to aid non-wear detection")
-              }
-            }
             if (sdwacc < sdcriter) {
               if (abs(maxwacc - minwacc) < racriter) {
                 NW[h,jj] = 1
               }
-            } else {
             }
           }
           CW = CW / (window2) #changed 30-1-2012, was window*sf
-          NWav[h,1] = (NW[h,1] + NW[h,2] + NW[h,3]) #indicator of non-wear
+          if (length(rmc.col.wear) == 0) {
+            NWav[h,1] = (NW[h,1] + NW[h,2] + NW[h,3]) #indicator of non-wear
+          }
           CWav[h,1] = max(c(CW[h,1],CW[h,2],CW[h,3])) #indicator of clipping
         }
         col_mli = 2
@@ -700,24 +721,24 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
         SDF = read.csv(selectdaysfile)
         if (useRDA == FALSE) {
           I = g.inspectfile(datafile, desiredtz=desiredtz,
-                                               rmc.dec=rmc.dec,configtz=configtz,
-                                               rmc.firstrow.acc = rmc.firstrow.acc,
-                                               rmc.firstrow.header = rmc.firstrow.header,
-                                               rmc.header.length = rmc.header.length,
-                                               rmc.col.acc = rmc.col.acc,
-                                               rmc.col.temp = rmc.col.temp, rmc.col.time=rmc.col.time,
-                                               rmc.unit.acc = rmc.unit.acc, rmc.unit.temp = rmc.unit.temp,
-                                               rmc.unit.time = rmc.unit.time,
-                                               rmc.format.time = rmc.format.time,
-                                               rmc.bitrate = rmc.bitrate, rmc.dynamic_range = rmc.dynamic_range,
-                                               rmc.unsignedbit = rmc.unsignedbit,
-                                               rmc.origin = rmc.origin,
-                                               rmc.desiredtz = rmc.desiredtz, rmc.sf = rmc.sf,
-                                               rmc.headername.sf = rmc.headername.sf,
-                                               rmc.headername.sn = rmc.headername.sn,
-                                               rmc.headername.recordingid = rmc.headername.sn,
-                                               rmc.header.structure = rmc.header.structure,
-                                               rmc.check4timegaps = rmc.check4timegaps)
+                            rmc.dec=rmc.dec,configtz=configtz,
+                            rmc.firstrow.acc = rmc.firstrow.acc,
+                            rmc.firstrow.header = rmc.firstrow.header,
+                            rmc.header.length = rmc.header.length,
+                            rmc.col.acc = rmc.col.acc,
+                            rmc.col.temp = rmc.col.temp, rmc.col.time=rmc.col.time,
+                            rmc.unit.acc = rmc.unit.acc, rmc.unit.temp = rmc.unit.temp,
+                            rmc.unit.time = rmc.unit.time,
+                            rmc.format.time = rmc.format.time,
+                            rmc.bitrate = rmc.bitrate, rmc.dynamic_range = rmc.dynamic_range,
+                            rmc.unsignedbit = rmc.unsignedbit,
+                            rmc.origin = rmc.origin,
+                            rmc.desiredtz = rmc.desiredtz, rmc.sf = rmc.sf,
+                            rmc.headername.sf = rmc.headername.sf,
+                            rmc.headername.sn = rmc.headername.sn,
+                            rmc.headername.recordingid = rmc.headername.sn,
+                            rmc.header.structure = rmc.header.structure,
+                            rmc.check4timegaps = rmc.check4timegaps)
         }
         hvars = g.extractheadervars(I)
         deviceSerialNumber = hvars$deviceSerialNumber
@@ -751,7 +772,6 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
     if (nrow(metalong) > 2) {
       starttime4 = round(as.numeric(starttime)) #numeric time but relative to the desiredtz
       time1 = seq(starttime4,(starttime4+(nrow(metalong)*ws2)-1),by=ws2)
-
       if (length(selectdaysfile) > 0 & round((24*(3600/ws2))+1) < length(time1)) { # (Millenium cohort)
         #===================================================================
         # All of the below needed for Millenium cohort
@@ -822,8 +842,6 @@ g.getmeta = function(datafile,desiredtz = c(),windowsizes = c(5,900,3600),
     for (ncolml in 2:ncol(metalong)) {
       metalong[,ncolml] = as.numeric(metalong[,ncolml])
     }
-
-    # closeAllConnections()
   } else {
     metalong=metashort=wday=wdayname=windowsizes = c()
   }
