@@ -34,6 +34,7 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
   if (length(which(ls() == "rmc.headername.recordingid")) == 0) rmc.headername.recordingid = c()
   if (length(which(ls() == "rmc.header.structure")) == 0) rmc.header.structure = c()
   if (length(which(ls() == "rmc.check4timegaps")) == 0) rmc.check4timegaps = FALSE
+  if (length(which(ls() == "rmc.col.wear")) == 0) rmc.col.wear = c()
   
   # function wrapper to read blocks of accelerationd data from various brands
   # the code identifies which accelerometer brand and data format it is
@@ -428,7 +429,8 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
                                  rmc.headername.sn = rmc.headername.sn,
                                  rmc.headername.recordingid = rmc.headername.sn,
                                  rmc.header.structure = rmc.header.structure,
-                                 rmc.check4timegaps = rmc.check4timegaps)
+                                 rmc.check4timegaps = rmc.check4timegaps,
+                                 rmc.col.wear=rmc.col.wear)
     },silent=TRUE)
     if (length(sf) == 0) sf = rmc.sf
     if (length(P) == 2) {
