@@ -3,12 +3,12 @@
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
-extern SEXP GGIR_numUnpack(SEXP);
-extern SEXP GGIR_resample(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _GGIR_numUnpack(SEXP);
+extern SEXP _GGIR_resample(SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
-    {"GGIR_numUnpack", (DL_FUNC) &GGIR_numUnpack, 1},
-    {"GGIR_resample",  (DL_FUNC) &GGIR_resample,  4},
+    {"_GGIR_numUnpack", (DL_FUNC) &_GGIR_numUnpack, 1},
+    {"_GGIR_resample",  (DL_FUNC) &_GGIR_resample,  4},
     {NULL, NULL, 0}
 };
 
